@@ -1,7 +1,7 @@
 ## Abundance matrix
 ## Coerce datasets to a count matrix (data from Desachy 2004)
-compiegne_count <- as_count(compiegne)
+data("compiegne", package = "folio")
 
 ## Plot rank vs abundance
-plot_rank(compiegne_count)
-plot_rank(compiegne_count, facet = FALSE)
+plot_rank(compiegne)
+plot_rank(compiegne, facet = TRUE)
