@@ -1,15 +1,14 @@
 ## Data from Magurran 1988, p. 162
-trees <- IncidenceMatrix(
+trees <- matrix(
   data = c(1, 1, 1, 0, 0, 0,
            1, 1, 1, 1, 1, 1,
            0, 0, 1, 0, 1, 0,
            0, 0, 0, 1, 1, 1,
            0, 0, 0, 0, 1, 1,
            0, 0, 0, 1, 0, 1),
-  nrow = 6, byrow = FALSE,
-  dimnames = list(c("1", "2", "3", "4", "5", "6"),
-                  c("Birch", "Oak", "Rowan", "Beech", "Hazel", "Holly"))
+  nrow = 6, byrow = FALSE
 )
+colnames(trees) <- c("Birch", "Oak", "Rowan", "Beech", "Hazel", "Holly")
 
 ## Whittaker's measure
 turnover(trees, "whittaker") # 1
@@ -18,8 +17,9 @@ turnover(trees, "whittaker") # 1
 turnover(trees, "cody") # 3
 
 ## Routledge's measures
-turnover(trees, method = c("routledge1", "routledge2", "routledge3"),
-         simplify = TRUE) ## 0.29 0.56 1.75
+turnover(trees, "routledge1") # 0.29
+turnover(trees, "routledge2") # 0.56
+turnover(trees, "routledge3") # 1.75
 
 ## Wilson and Shmida's measure
 turnover(trees, "wilson") # 1
