@@ -1,10 +1,9 @@
 test_that("Compute thresholds", {
   skip_if_not_installed("folio")
   data("compiegne", package = "folio")
-  counts <- arkhe::as_count(compiegne)
 
-  expect_type(eppm(counts), "double") # matrix
-  expect_type(pvi(counts), "double") # matrix
+  expect_snapshot(eppm(compiegne))
+  expect_snapshot(pvi(compiegne))
 })
 test_that("Binomial coefficient", {
   expect_equal(combination(4, 3), 4)
@@ -21,7 +20,3 @@ test_that("Confidence interval for a proportion", {
   expect_length(confidence_proportion(1:10), 10)
   expect_error(confidence_proportion(LETTERS))
 })
-test_that("Jackknife estimation", {
-  jack <- stats_jackknife(1:10, sum)
-  expect_equal(round(jack, 2), c(mean = 49.50, bias = -49.50, error = 8.62))
-})
